"use strict";
/*
  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

  Licensed under the Apache License, Version 2.0 (the "License").
  You may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGraphqlCallExpression = exports.getGraphqlQueryForModel = exports.ActionType = void 0;
const pluralize_1 = require("pluralize");
const codegen_ui_1 = require("@aws-amplify/codegen-ui");
const typescript_1 = require("typescript");
const imports_1 = require("../imports");
var ActionType;
(function (ActionType) {
    ActionType["CREATE"] = "create";
    ActionType["UPDATE"] = "update";
    ActionType["DELETE"] = "delete";
    ActionType["LIST"] = "list";
    ActionType["GET"] = "get";
})(ActionType = exports.ActionType || (exports.ActionType = {}));
const getGraphqlQueryForModel = (action, model) => {
    switch (action) {
        case ActionType.CREATE:
            return `create${model}`;
        case ActionType.UPDATE:
            return `update${model}`;
        case ActionType.DELETE:
            return `delete${model}`;
        case ActionType.GET:
            return `get${model}`;
        case ActionType.LIST:
            return `list${(0, pluralize_1.plural)(model)}`;
        default:
            throw new codegen_ui_1.InvalidInputError(`Action ${action} has no corresponding GraphQL operation`);
    }
};
exports.getGraphqlQueryForModel = getGraphqlQueryForModel;
/**
 * Returns a GraphQL call expression and adds to importCollection.
 *
 * @example
 * ```
 * API.graphql({
 *  query: createTodo,
 *  variables: {
 *    input: {
 *      inputs
 *    },
 *  },
 * });
 * ```
 */
const getGraphqlCallExpression = (action, model, importCollection, inputs, filters) => {
    const query = (0, exports.getGraphqlQueryForModel)(action, model);
    const graphqlVariables = [];
    importCollection.addMappedImport(imports_1.ImportValue.API);
    if (inputs) {
        graphqlVariables.push(typescript_1.factory.createPropertyAssignment(typescript_1.factory.createIdentifier('input'), typescript_1.factory.createObjectLiteralExpression(inputs, true)));
    }
    if (action === ActionType.LIST || action === ActionType.GET) {
        importCollection.addGraphqlQueryImport(query);
        // filter applies to list
        if (filters) {
            graphqlVariables.push(typescript_1.factory.createPropertyAssignment(typescript_1.factory.createIdentifier('filter'), typescript_1.factory.createObjectLiteralExpression(filters, true)));
        }
    }
    else {
        importCollection.addGraphqlMutationImport(query);
    }
    importCollection.addModelImport(model);
    const graphqlOptions = [
        typescript_1.factory.createPropertyAssignment(typescript_1.factory.createIdentifier('query'), typescript_1.factory.createIdentifier(query)),
    ];
    if (graphqlVariables.length > 0) {
        graphqlOptions.push(typescript_1.factory.createPropertyAssignment(typescript_1.factory.createIdentifier('variables'), typescript_1.factory.createObjectLiteralExpression(graphqlVariables)));
    }
    return typescript_1.factory.createCallExpression(typescript_1.factory.createPropertyAccessExpression(typescript_1.factory.createIdentifier('API'), typescript_1.factory.createIdentifier('graphql')), undefined, [typescript_1.factory.createObjectLiteralExpression(graphqlOptions, true)]);
};
exports.getGraphqlCallExpression = getGraphqlCallExpression;
//# sourceMappingURL=graphql.js.map